diff --git a/src/Socket/ConnectionInterface.php b/src/Socket/ConnectionInterface.php
index e976f19..2880d7f 100644
--- a/src/Socket/ConnectionInterface.php
+++ b/src/Socket/ConnectionInterface.php
@@ -2,10 +2,10 @@
 namespace mfmdevsystem\socket;
 
 /**
  * The version of Ratchet being used
  * @var string
  */
-const VERSION = 'Ratchet/0.4.4';
+const VERSION = 'mfmdevsyste/socket/0.4.9';
 
 /**
  * A proxy object representing a connection to the application
@@ -2,10 +2,10 @@
 
 /**
- * The version of Ratchet being used
+ * The version of socket being used
  * @var string
  */